@@ -1,10 +1,10 @@
 /* complex/test.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -46,6 +46,19 @@ struct fz
   double fy;
 };
 
+struct fzz
+{
+  char *name;
+  gsl_complex (*f) (gsl_complex z1, gsl_complex z2);
+  double x1;
+  double y1;
+  double x2;
+  double y2;
+  double fx;
+  double fy;
+};
+
+
 struct freal
 {
   char *name;
@@ -73,17 +86,33 @@ struct fz listz[] =
   {"", 0, 0, 0, 0, 0}
 };
 
+struct fzz listzz[] =
+{
+  {FN (pow), ARG(0.0,0.0), ARG(0.0,0.0), RES(1.0, 0.0)},
+#include "results2.h"
+  {"", 0, 0, 0, 0, 0, 0, 0}
+};
+
 struct freal listreal[] =
 {
 #include "results_real.h"
   {"", 0, 0, 0, 0}
 };
 
+#ifndef TEST_FACTOR
+#ifdef RELEASED
+#define TEST_FACTOR 100.0  
+#else
+#define TEST_FACTOR 1.0
+#endif
+#endif
 
 int
 main (void)
 {
   size_t i = 0;
+  const double tol = TEST_FACTOR * 10 * GSL_DBL_EPSILON;
+  const double tolf = TEST_FACTOR * 10 * GSL_FLT_EPSILON;
 
   gsl_ieee_env_setup();
 
@@ -94,9 +123,8 @@ main (void)
       double t = 2.0 * M_PI * i / 5 ;
       double x = r * cos(t), y = r * sin(t) ;
       gsl_complex z = gsl_complex_polar (r, t) ;
-      gsl_test_rel (GSL_REAL(z), x, 10 * GSL_DBL_EPSILON, "gsl_complex_polar real part at (r=%g,t=%g)", r, t);
-      
-      gsl_test_rel (GSL_IMAG(z), y, 10 * GSL_DBL_EPSILON, "gsl_complex_polar imag part at (r=%g,t=%g)", r, t);
+      gsl_test_rel (GSL_REAL(z), x, tol, "gsl_complex_polar real part at (r=%g,t=%g)", r, t);
+      gsl_test_rel (GSL_IMAG(z), y, tol, "gsl_complex_polar imag part at (r=%g,t=%g)", r, t);
     }
     
     i = 0;
@@ -106,7 +134,7 @@ main (void)
       struct f t = list[i];
       gsl_complex z = gsl_complex_rect (t.x, t.y);
       double f = (t.f) (z);
-      gsl_test_rel (f, t.fx, 10 * GSL_DBL_EPSILON, "%s at (%g,%g)", t.name, t.x, t.y);
+      gsl_test_rel (f, t.fx, tol, "%s at (%g,%g)", t.name, t.x, t.y);
       i++;
     }
 
@@ -128,8 +156,34 @@ main (void)
       printf("ey = "); gsl_ieee_fprintf_double (stdout, &t.fy); printf("\n");
 #endif
 
-      gsl_test_rel (fx, t.fx, 10 * GSL_DBL_EPSILON, "%s real part at (%g,%g)", t.name, t.x, t.y);
-      gsl_test_rel (fy, t.fy, 10 * GSL_DBL_EPSILON, "%s imag part at (%g,%g)", t.name, t.x, t.y);
+      gsl_test_rel (fx, t.fx, tol, "%s real part at (%g,%g)", t.name, t.x, t.y);
+      gsl_test_rel (fy, t.fy, tol, "%s imag part at (%g,%g)", t.name, t.x, t.y);
+      i++;
+    }
+
+  i = 0;
+
+  while (listzz[i].f)
+    {
+      struct fzz t = listzz[i];
+      gsl_complex z1 = gsl_complex_rect (t.x1, t.y1);
+      gsl_complex z2 = gsl_complex_rect (t.x2, t.y2);
+      gsl_complex fz = (t.f) (z1, z2);
+      double fx = GSL_REAL (fz), fy = GSL_IMAG (fz);
+
+#ifdef DEBUG
+      printf("x1 = "); gsl_ieee_fprintf_double (stdout, &t.x1); printf("\n");
+      printf("y1 = "); gsl_ieee_fprintf_double (stdout, &t.y1); printf("\n");
+      printf("x2 = "); gsl_ieee_fprintf_double (stdout, &t.x2); printf("\n");
+      printf("y2 = "); gsl_ieee_fprintf_double (stdout, &t.y2); printf("\n");
+      printf("fx = "); gsl_ieee_fprintf_double (stdout, &fx); printf("\n");
+      printf("ex = "); gsl_ieee_fprintf_double (stdout, &t.fx); printf("\n");
+      printf("fy = "); gsl_ieee_fprintf_double (stdout, &fy); printf("\n");
+      printf("ey = "); gsl_ieee_fprintf_double (stdout, &t.fy); printf("\n");
+#endif
+
+      gsl_test_rel (fx, t.fx, tolf, "%s real part at (%g,%g;%g,%g)", t.name, t.x1, t.y1, t.x2, t.y2);
+      gsl_test_rel (fy, t.fy, tolf, "%s imag part at (%g,%g;%g,%g)", t.name, t.x1, t.y1, t.x2, t.y2);
       i++;
     }
 
@@ -150,8 +204,8 @@ main (void)
       printf("ey = "); gsl_ieee_fprintf_double (stdout, &t.fy); printf("\n");
 #endif
 
-      gsl_test_rel (fx, t.fx, 10 * GSL_DBL_EPSILON, "%s real part at (%g,0)", t.name, t.x);
-      gsl_test_rel (fy, t.fy, 10 * GSL_DBL_EPSILON, "%s imag part at (%g,0)", t.name, t.x);
+      gsl_test_rel (fx, t.fx, tol, "%s real part at (%g,0)", t.name, t.x);
+      gsl_test_rel (fy, t.fy, tol, "%s imag part at (%g,0)", t.name, t.x);
       i++;
     }
 
