@@ -3,7 +3,7 @@
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -119,3 +119,22 @@ gsl_histogram_sigma (const gsl_histogram * h)
   }
 }
 
+
+/*
+  sum up all bins of histogram
+ */
+
+double 
+gsl_histogram_sum(const gsl_histogram * h)
+{
+  double sum=0;
+  size_t i=0;
+  size_t n;
+  n=h->n;
+
+  while(i < n)
+    sum += h->bin[i++];
+
+  return sum;
+}
+
