@@ -2,11 +2,13 @@
  *
  * Copyright (C) 2000  Thomas Walter
  *
- * 3 May 2000: Modified for GSL by Brian Gough
+ * 03 May 2000: Modified for GSL by Brian Gough
+ * 29 Jul 2005: Additions by Gerard Jungman
+ * Copyright (C) 2000,2001, 2002, 2003, 2005, 2007 Brian Gough, Gerard Jungman
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
+ * Free Software Foundation; either version 3, or (at your option) any
  * later version.
  *
  * This source is distributed in the hope that it will be useful, but WITHOUT
@@ -21,7 +23,7 @@
  *    periodic cubic splines
  *    approximating splines
  *
- * This algorthm does:
+ * This algorithm does:
  *   A = L * L'
  * with
  *   L  := lower left triangle matrix
@@ -38,6 +40,14 @@
 #include <gsl/gsl_blas.h>
 #include <gsl/gsl_linalg.h>
 
+static inline 
+double
+quiet_sqrt (double x)  
+     /* avoids runtime error, for checking matrix for positive definiteness */
+{
+  return (x >= 0) ? sqrt(x) : GSL_NAN;
+}
+
 int
 gsl_linalg_cholesky_decomp (gsl_matrix * A)
 {
@@ -59,7 +69,7 @@ gsl_linalg_cholesky_decomp (gsl_matrix * A)
 
       double A_00 = gsl_matrix_get (A, 0, 0);
       
-      double L_00 = sqrt(A_00);
+      double L_00 = quiet_sqrt(A_00);
       
       if (A_00 <= 0)
         {
@@ -75,7 +85,7 @@ gsl_linalg_cholesky_decomp (gsl_matrix * A)
           
           double L_10 = A_10 / L_00;
           double diag = A_11 - L_10 * L_10;
-          double L_11 = sqrt(diag);
+          double L_11 = quiet_sqrt(diag);
           
           if (diag <= 0)
             {
@@ -118,7 +128,7 @@ gsl_linalg_cholesky_decomp (gsl_matrix * A)
             double sum = gsl_blas_dnrm2 (&dk.vector);
             double diag = A_kk - sum * sum;
 
-            double L_kk = sqrt(diag);
+            double L_kk = quiet_sqrt(diag);
             
             if (diag <= 0)
               {
@@ -215,4 +225,42 @@ gsl_linalg_cholesky_svx (const gsl_matrix * LLT,
 }
 
 
+int
+gsl_linalg_cholesky_decomp_unit(gsl_matrix * A, gsl_vector * D)
+{
+  const size_t N = A->size1;
+  size_t i, j;
 
+  /* initial Cholesky */
+  int stat_chol = gsl_linalg_cholesky_decomp(A);
+
+  if(stat_chol == GSL_SUCCESS)
+  {
+    /* calculate D from diagonal part of initial Cholesky */
+    for(i = 0; i < N; ++i)
+    {
+      const double C_ii = gsl_matrix_get(A, i, i);
+      gsl_vector_set(D, i, C_ii*C_ii);
+    }
+
+    /* multiply initial Cholesky by 1/sqrt(D) on the right */
+    for(i = 0; i < N; ++i)
+    {
+      for(j = 0; j < N; ++j)
+      {
+        gsl_matrix_set(A, i, j, gsl_matrix_get(A, i, j) / sqrt(gsl_vector_get(D, j)));
+      }
+    }
+
+    /* Because the initial Cholesky contained both L and transpose(L),
+       the result of the multiplication is not symmetric anymore;
+       but the lower triangle _is_ correct. Therefore we reflect
+       it to the upper triangle and declare victory.
+       */
+    for(i = 0; i < N; ++i)
+      for(j = i + 1; j < N; ++j)
+        gsl_matrix_set(A, i, j, gsl_matrix_get(A, j, i));
+  }
+
+  return stat_chol;
+}
