@@ -1,10 +1,10 @@
 /* linalg/householder.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -67,8 +67,6 @@ gsl_linalg_householder_hm (double tau, const gsl_vector * v, gsl_matrix * A)
 {
   /* applies a householder transformation v,tau to matrix m */
 
-  size_t i, j;
-
   if (tau == 0.0)
     {
       return GSL_SUCCESS;
@@ -78,7 +76,8 @@ gsl_linalg_householder_hm (double tau, const gsl_vector * v, gsl_matrix * A)
   {
     gsl_vector_const_view v1 = gsl_vector_const_subvector (v, 1, v->size - 1);
     gsl_matrix_view A1 = gsl_matrix_submatrix (A, 1, 0, A->size1 - 1, A->size2);
-    
+    size_t j;
+
     for (j = 0; j < A->size2; j++)
       {
         double wj = 0.0;
@@ -95,36 +94,40 @@ gsl_linalg_householder_hm (double tau, const gsl_vector * v, gsl_matrix * A)
       }
   }
 #else
-  for (j = 0; j < A->size2; j++)
-    {
-      /* Compute wj = Akj vk */
-
-      double wj = gsl_matrix_get(A,0,j);  
-
-      for (i = 1; i < A->size1; i++)  /* note, computed for v(0) = 1 above */
-        {
-          wj += gsl_matrix_get(A,i,j) * gsl_vector_get(v,i);
-        }
-
-      /* Aij = Aij - tau vi wj */
-
-      /* i = 0 */
+  {
+    size_t i, j;
+    
+    for (j = 0; j < A->size2; j++)
       {
-        double A0j = gsl_matrix_get (A, 0, j);
-        gsl_matrix_set (A, 0, j, A0j - tau *  wj);
-      }
-
-      /* i = 1 .. M-1 */
-
-      for (i = 1; i < A->size1; i++)
+        /* Compute wj = Akj vk */
+        
+        double wj = gsl_matrix_get(A,0,j);  
+        
+        for (i = 1; i < A->size1; i++)  /* note, computed for v(0) = 1 above */
+          {
+            wj += gsl_matrix_get(A,i,j) * gsl_vector_get(v,i);
+          }
+        
+        /* Aij = Aij - tau vi wj */
+        
+        /* i = 0 */
         {
-          double Aij = gsl_matrix_get (A, i, j);
-          double vi = gsl_vector_get (v, i);
-          gsl_matrix_set (A, i, j, Aij - tau * vi * wj);
+          double A0j = gsl_matrix_get (A, 0, j);
+          gsl_matrix_set (A, 0, j, A0j - tau *  wj);
         }
-    }
+        
+        /* i = 1 .. M-1 */
+        
+        for (i = 1; i < A->size1; i++)
+          {
+            double Aij = gsl_matrix_get (A, i, j);
+            double vi = gsl_vector_get (v, i);
+            gsl_matrix_set (A, i, j, Aij - tau * vi * wj);
+          }
+      }
+  }
 #endif
-
+    
   return GSL_SUCCESS;
 }
 
@@ -134,8 +137,6 @@ gsl_linalg_householder_mh (double tau, const gsl_vector * v, gsl_matrix * A)
   /* applies a householder transformation v,tau to matrix m from the
      right hand side in order to zero out rows */
 
-  size_t i, j;
-
   if (tau == 0)
     return GSL_SUCCESS;
 
@@ -145,6 +146,7 @@ gsl_linalg_householder_mh (double tau, const gsl_vector * v, gsl_matrix * A)
   {
     gsl_vector_const_view v1 = gsl_vector_const_subvector (v, 1, v->size - 1);
     gsl_matrix_view A1 = gsl_matrix_submatrix (A, 0, 1, A->size1, A->size2-1);
+    size_t i;
 
     for (i = 0; i < A->size1; i++)
       {
@@ -162,33 +164,37 @@ gsl_linalg_householder_mh (double tau, const gsl_vector * v, gsl_matrix * A)
       }
   }
 #else
-  for (i = 0; i < A->size1; i++)
-    {
-      double wi = gsl_matrix_get(A,i,0);  
-
-      for (j = 1; j < A->size2; j++)  /* note, computed for v(0) = 1 above */
-        {
-          wi += gsl_matrix_get(A,i,j) * gsl_vector_get(v,j);
-        }
-      
-      /* j = 0 */
-      
+  {
+    size_t i, j;
+    
+    for (i = 0; i < A->size1; i++)
       {
-        double Ai0 = gsl_matrix_get (A, i, 0);
-        gsl_matrix_set (A, i, 0, Ai0 - tau *  wi);
-      }
-
-      /* j = 1 .. N-1 */
-      
-      for (j = 1; j < A->size2; j++) 
+        double wi = gsl_matrix_get(A,i,0);  
+        
+        for (j = 1; j < A->size2; j++)  /* note, computed for v(0) = 1 above */
+          {
+            wi += gsl_matrix_get(A,i,j) * gsl_vector_get(v,j);
+          }
+        
+        /* j = 0 */
+        
         {
-          double vj = gsl_vector_get (v, j);
-          double Aij = gsl_matrix_get (A, i, j);
-          gsl_matrix_set (A, i, j, Aij - tau * wi * vj);
+          double Ai0 = gsl_matrix_get (A, i, 0);
+          gsl_matrix_set (A, i, 0, Ai0 - tau *  wi);
         }
-    }
+        
+        /* j = 1 .. N-1 */
+        
+        for (j = 1; j < A->size2; j++) 
+          {
+            double vj = gsl_vector_get (v, j);
+            double Aij = gsl_matrix_get (A, i, j);
+            gsl_matrix_set (A, i, j, Aij - tau * wi * vj);
+          }
+      }
+  }
 #endif
-
+    
   return GSL_SUCCESS;
 }
 
@@ -235,10 +241,10 @@ gsl_linalg_householder_hm1 (double tau, gsl_matrix * A)
      build up from the identity matrix, using the first column of A as
      a householder vector */
 
-  size_t i, j;
-
   if (tau == 0)
     {
+      size_t i,j;
+
       gsl_matrix_set (A, 0, 0, 1.0);
       
       for (j = 1; j < A->size2; j++)
@@ -260,6 +266,7 @@ gsl_linalg_householder_hm1 (double tau, gsl_matrix * A)
   {
     gsl_matrix_view A1 = gsl_matrix_submatrix (A, 1, 0, A->size1 - 1, A->size2);
     gsl_vector_view v1 = gsl_matrix_column (&A1.matrix, 0);
+    size_t j;
 
     for (j = 1; j < A->size2; j++)
       {
@@ -280,35 +287,39 @@ gsl_linalg_householder_hm1 (double tau, gsl_matrix * A)
     gsl_matrix_set (A, 0, 0, 1.0 - tau);
   }
 #else
-  for (j = 1; j < A->size2; j++)
-    {
-      double wj = 0.0;   /* A0j * v0 */
-
-      for (i = 1; i < A->size1; i++)
-        {
-          double vi = gsl_matrix_get(A, i, 0);
-          wj += gsl_matrix_get(A,i,j) * vi;
-        }
-
-      /* A = A - tau v w' */
-
-      gsl_matrix_set (A, 0, j, - tau *  wj);
-      
-      for (i = 1; i < A->size1; i++)
-        {
-          double vi = gsl_matrix_get (A, i, 0);
-          double Aij = gsl_matrix_get (A, i, j);
-          gsl_matrix_set (A, i, j, Aij - tau * vi * wj);
-        }
-    }
-
-  for (i = 1; i < A->size1; i++)
-    {
-      double vi = gsl_matrix_get(A, i, 0);
-      gsl_matrix_set(A, i, 0, -tau * vi);
-    }
-
-  gsl_matrix_set (A, 0, 0, 1.0 - tau);
+  {
+    size_t i, j;
+    
+    for (j = 1; j < A->size2; j++)
+      {
+        double wj = 0.0;   /* A0j * v0 */
+        
+        for (i = 1; i < A->size1; i++)
+          {
+            double vi = gsl_matrix_get(A, i, 0);
+            wj += gsl_matrix_get(A,i,j) * vi;
+          }
+        
+        /* A = A - tau v w' */
+        
+        gsl_matrix_set (A, 0, j, - tau *  wj);
+        
+        for (i = 1; i < A->size1; i++)
+          {
+            double vi = gsl_matrix_get (A, i, 0);
+            double Aij = gsl_matrix_get (A, i, j);
+            gsl_matrix_set (A, i, j, Aij - tau * vi * wj);
+          }
+      }
+    
+    for (i = 1; i < A->size1; i++)
+      {
+        double vi = gsl_matrix_get(A, i, 0);
+        gsl_matrix_set(A, i, 0, -tau * vi);
+      }
+    
+    gsl_matrix_set (A, 0, 0, 1.0 - tau);
+  }
 #endif
 
   return GSL_SUCCESS;
