@@ -1,10 +1,10 @@
 /* linalg/svd.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -50,7 +50,7 @@ int
 gsl_linalg_SV_decomp (gsl_matrix * A, gsl_matrix * V, gsl_vector * S, 
                       gsl_vector * work)
 {
-  size_t a, b, i, j;
+  size_t a, b, i, j, iter;
 
   const size_t M = A->size1;
   const size_t N = A->size2;
@@ -113,7 +113,8 @@ gsl_linalg_SV_decomp (gsl_matrix * A, gsl_matrix * V, gsl_vector * S,
     /* Progressively reduce the matrix until it is diagonal */
     
     b = N - 1;
-    
+    iter = 0;
+
     while (b > 0)
       {
         double fbm1 = gsl_vector_get (&f.vector, b - 1);
@@ -140,6 +141,14 @@ gsl_linalg_SV_decomp (gsl_matrix * A, gsl_matrix * V, gsl_vector * S,
             
             a--;
           }
+
+        iter++;
+        
+        if (iter > 100 * N) 
+          {
+            GSL_ERROR("SVD decomposition failed to converge", GSL_EMAXITER);
+          }
+
         
         {
           const size_t n_block = b - a + 1;
@@ -438,7 +447,7 @@ gsl_linalg_SV_solve (const gsl_matrix * U,
 int
 gsl_linalg_SV_decomp_jacobi (gsl_matrix * A, gsl_matrix * Q, gsl_vector * S)
 {
-  if (Q->size1 < Q->size2)
+  if (A->size1 < A->size2)
     {
       /* FIXME: only implemented  M>=N case so far */
 
@@ -467,9 +476,9 @@ gsl_linalg_SV_decomp_jacobi (gsl_matrix * A, gsl_matrix * Q, gsl_vector * S)
       /* Initialize the rotation counter and the sweep counter. */
       int count = 1;
       int sweep = 0;
-      int sweepmax = N;
+      int sweepmax = 5*N;
 
-      double tolerance = 10 * GSL_DBL_EPSILON;
+      double tolerance = 10 * M * GSL_DBL_EPSILON;
 
       /* Always do at least 12 sweeps. */
       sweepmax = GSL_MAX (sweepmax, 12);
@@ -477,6 +486,16 @@ gsl_linalg_SV_decomp_jacobi (gsl_matrix * A, gsl_matrix * Q, gsl_vector * S)
       /* Set Q to the identity matrix. */
       gsl_matrix_set_identity (Q);
 
+      /* Store the column error estimates in S, for use during the
+         orthogonalization */
+
+      for (j = 0; j < N; j++)
+        {
+          gsl_vector_view cj = gsl_matrix_column (A, j);
+          double sj = gsl_blas_dnrm2 (&cj.vector);
+          gsl_vector_set(S, j, GSL_DBL_EPSILON * sj);
+        }
+    
       /* Orthogonalize A by plane rotations. */
 
       while (count > 0 && sweep <= sweepmax)
@@ -492,63 +511,49 @@ gsl_linalg_SV_decomp_jacobi (gsl_matrix * A, gsl_matrix * Q, gsl_vector * S)
                   double b = 0.0;
                   double p = 0.0;
                   double q = 0.0;
-                  double r = 0.0;
                   double cosine, sine;
                   double v;
+                  double abserr_a, abserr_b;
+                  int sorted, orthog, noisya, noisyb;
 
                   gsl_vector_view cj = gsl_matrix_column (A, j);
                   gsl_vector_view ck = gsl_matrix_column (A, k);
 
                   gsl_blas_ddot (&cj.vector, &ck.vector, &p);
+                  p *= 2.0 ;  /* equation 9a:  p = 2 x.y */
 
                   a = gsl_blas_dnrm2 (&cj.vector);
                   b = gsl_blas_dnrm2 (&ck.vector);
 
-                  q = a * a;
-                  r = b * b;
+                  q = a * a - b * b;
+                  v = hypot(p, q);
 
-                  /* NOTE: this could be handled better by scaling
-                   * the calculation of the inner products above.
-                   * But I'm too lazy. This will have to do. [GJ]
-                   */
+                  /* test for columns j,k orthogonal, or dominant errors */
 
-                  /* FIXME: This routine is a hack. We need to get the
-                     state of the art in Jacobi SVD's here ! */
+                  abserr_a = gsl_vector_get(S,j);
+                  abserr_b = gsl_vector_get(S,k);
 
-                  /* This is an adhoc method of testing for a "zero"
-                     singular value. We consider it to be zero if it
-                     is sufficiently small compared with the currently
-                     leading column. Note that b <= a is guaranteed by
-                     the sweeping algorithm. BJG */
+                  sorted = (gsl_coerce_double(a) >= gsl_coerce_double(b));
+                  orthog = (fabs (p) <= tolerance * gsl_coerce_double(a * b));
+                  noisya = (a < abserr_a);
+                  noisyb = (b < abserr_b);
 
-                  if (b <= tolerance * a)
+                  if (sorted && (orthog || noisya || noisyb))
                     {
-                      /* probably |b| = 0 */
-                      count--;
-                      continue;
-                    }
-
-                  if (fabs (p) <= tolerance * a * b)
-                    {
-                      /* columns j,k orthogonal
-                       * note that p*p/(q*r) is automatically <= 1.0
-                       */
                       count--;
                       continue;
                     }
 
                   /* calculate rotation angles */
-                  if (q < r)
+                  if (v == 0 || !sorted)
                     {
                       cosine = 0.0;
                       sine = 1.0;
                     }
                   else
                     {
-                      q -= r;
-                      v = hypot (2.0 * p, q);
-                      cosine = sqrt ((v + q) / (2.0 * v));
-                      sine = p / (v * cosine);
+                      cosine = sqrt((v + q) / (2.0 * v));
+                      sine = p / (2.0 * v * cosine);
                     }
 
                   /* apply rotation to A */
@@ -560,6 +565,9 @@ gsl_linalg_SV_decomp_jacobi (gsl_matrix * A, gsl_matrix * Q, gsl_vector * S)
                       gsl_matrix_set (A, i, k, -Aij * sine + Aik * cosine);
                     }
 
+                  gsl_vector_set(S, j, fabs(cosine) * abserr_a + fabs(sine) * abserr_b);
+                  gsl_vector_set(S, k, fabs(sine) * abserr_a + fabs(cosine) * abserr_b);
+
                   /* apply rotation to Q */
                   for (i = 0; i < N; i++)
                     {
