@@ -1,11 +1,10 @@
 /* linalg/tridiag.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2002, 2004 Gerard Jungman,
- * Brian Gough, David Necas
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2002, 2004, 2007 Gerard Jungman, Brian Gough, David Necas
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -15,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author: G. Jungman */
@@ -43,7 +42,7 @@ solve_tridiag(
   double x[], size_t x_stride,
   size_t N)
 {
-  int status;
+  int status = GSL_SUCCESS;
   double *gamma = (double *) malloc (N * sizeof (double));
   double *alpha = (double *) malloc (N * sizeof (double));
   double *c = (double *) malloc (N * sizeof (double));
@@ -51,7 +50,7 @@ solve_tridiag(
 
   if (gamma == 0 || alpha == 0 || c == 0 || z == 0)
     {
-      status = GSL_ENOMEM;
+      GSL_ERROR("failed to allocate working space", GSL_ENOMEM);
     }
   else
     {
@@ -65,10 +64,17 @@ solve_tridiag(
       alpha[0] = diag[0];
       gamma[0] = offdiag[0] / alpha[0];
 
+      if (alpha[0] == 0) {
+        status = GSL_EZERODIV;
+      }
+
       for (i = 1; i < N - 1; i++)
         {
           alpha[i] = diag[d_stride * i] - offdiag[o_stride*(i - 1)] * gamma[i - 1];
           gamma[i] = offdiag[o_stride * i] / alpha[i];
+          if (alpha[i] == 0) {
+            status = GSL_EZERODIV;
+          }
         }
 
       if (N > 1) 
@@ -96,8 +102,6 @@ solve_tridiag(
               x[x_stride * i] = c[i] - gamma[i] * x[x_stride * (i + 1)];
             }
         }
-
-      status = GSL_SUCCESS;
     }
 
   if (z != 0)
@@ -109,6 +113,10 @@ solve_tridiag(
   if (gamma != 0)
     free (gamma);
 
+  if (status == GSL_EZERODIV) {
+    GSL_ERROR ("matrix must be positive definite", status);
+  }
+
   return status;
 }
 
@@ -129,13 +137,13 @@ solve_tridiag_nonsym(
   double x[], size_t x_stride,
   size_t N)
 {
-  int status;
+  int status = GSL_SUCCESS;
   double *alpha = (double *) malloc (N * sizeof (double));
   double *z = (double *) malloc (N * sizeof (double));
 
   if (alpha == 0 || z == 0)
     {
-      status = GSL_ENOMEM;
+      GSL_ERROR("failed to allocate working space", GSL_ENOMEM);
     }
   else
     {
@@ -148,16 +156,18 @@ solve_tridiag_nonsym(
        */
       alpha[0] = diag[0];
       z[0] = rhs[0];
+      
+      if (alpha[0] == 0) {
+        status = GSL_EZERODIV;
+      }
 
       for (i = 1; i < N; i++)
         {
           const double t = belowdiag[b_stride*(i - 1)]/alpha[i-1];
           alpha[i] = diag[d_stride*i] - t*abovediag[a_stride*(i - 1)];
           z[i] = rhs[r_stride*i] - t*z[i-1];
-          /* FIXME!!! */
           if (alpha[i] == 0) {
             status = GSL_EZERODIV;
-            goto solve_tridiag_nonsym_END;
           }
         }
 
@@ -170,16 +180,17 @@ solve_tridiag_nonsym(
               x[x_stride * i] = (z[i] - abovediag[a_stride*i] * x[x_stride * (i + 1)])/alpha[i];
             }
         }
-
-      status = GSL_SUCCESS;
     }
 
-solve_tridiag_nonsym_END:
   if (z != 0)
     free (z);
   if (alpha != 0)
     free (alpha);
 
+  if (status == GSL_EZERODIV) {
+    GSL_ERROR ("matrix must be positive definite", status);
+  }
+
   return status;
 }
 
@@ -202,7 +213,7 @@ solve_cyc_tridiag(
   double x[], size_t x_stride,
   size_t N)
 {
-  int status;
+  int status = GSL_SUCCESS;
   double * delta = (double *) malloc (N * sizeof (double));
   double * gamma = (double *) malloc (N * sizeof (double));
   double * alpha = (double *) malloc (N * sizeof (double));
@@ -211,7 +222,7 @@ solve_cyc_tridiag(
 
   if (delta == 0 || gamma == 0 || alpha == 0 || c == 0 || z == 0)
     {
-      status = GSL_ENOMEM;
+      GSL_ERROR("failed to allocate working space", GSL_ENOMEM);
     }
   else
     {
@@ -230,11 +241,18 @@ solve_cyc_tridiag(
       gamma[0] = offdiag[0] / alpha[0];
       delta[0] = offdiag[o_stride * (N-1)] / alpha[0];
 
+      if (alpha[0] == 0) {
+        status = GSL_EZERODIV;
+      }
+
       for (i = 1; i < N - 2; i++)
         {
           alpha[i] = diag[d_stride * i] - offdiag[o_stride * (i-1)] * gamma[i - 1];
           gamma[i] = offdiag[o_stride * i] / alpha[i];
           delta[i] = -delta[i - 1] * offdiag[o_stride * (i-1)] / alpha[i];
+          if (alpha[i] == 0) {
+            status = GSL_EZERODIV;
+          }
         }
 
       for (i = 0; i < N - 2; i++)
@@ -275,8 +293,6 @@ solve_cyc_tridiag(
               x[x_stride * i] = c[i] - gamma[i] * x[x_stride * (i + 1)] - delta[i] * x[x_stride * (N - 1)];
             }
         }
-
-      status = GSL_SUCCESS;
     }
 
   if (z != 0)
@@ -290,6 +306,10 @@ solve_cyc_tridiag(
   if (delta != 0)
     free (delta);
 
+  if (status == GSL_EZERODIV) {
+    GSL_ERROR ("matrix must be positive definite", status);
+  }
+
   return status;
 }
 
@@ -312,19 +332,20 @@ int solve_cyc_tridiag_nonsym(
   double x[], size_t x_stride,
   size_t N)
 {
-  int status;
+  int status = GSL_SUCCESS;
   double *alpha = (double *) malloc (N * sizeof (double));
   double *zb = (double *) malloc (N * sizeof (double));
   double *zu = (double *) malloc (N * sizeof (double));
   double *w = (double *) malloc (N * sizeof (double));
-  double beta;
 
   if (alpha == 0 || zb == 0 || zu == 0 || w == 0)
     {
-      status = GSL_ENOMEM;
+      GSL_ERROR("failed to allocate working space", GSL_ENOMEM);
     }
   else
     {
+      double beta;
+
       /* Bidiagonalization (eliminating belowdiag)
          & rhs update
          diag' = alpha
@@ -342,6 +363,9 @@ int solve_cyc_tridiag_nonsym(
       zu[0] = beta;
       alpha[0] = diag[0] - beta;
 
+      if (alpha[0] == 0) {
+        status = GSL_EZERODIV;
+      }
 
       { 
         size_t i;
@@ -354,7 +378,6 @@ int solve_cyc_tridiag_nonsym(
           /* FIXME!!! */
           if (alpha[i] == 0) {
             status = GSL_EZERODIV;
-            goto solve_cyc_tridiag_nonsym_END;
           }
         }
       }
@@ -370,11 +393,9 @@ int solve_cyc_tridiag_nonsym(
         /* FIXME!!! */
         if (alpha[i] == 0) {
           status = GSL_EZERODIV;
-          goto solve_cyc_tridiag_nonsym_END;
         }
       }
 
-
       /* backsubstitution */
       {
         size_t i, j;
@@ -394,7 +415,6 @@ int solve_cyc_tridiag_nonsym(
         /* FIXME!!! */
         if (vw + 1 == 0) {
           status = GSL_EZERODIV;
-          goto solve_cyc_tridiag_nonsym_END;
         }
 
         {
@@ -403,11 +423,8 @@ int solve_cyc_tridiag_nonsym(
             x[i] -= vx/(1 + vw)*w[i];
         }
       }
-
-      status = GSL_SUCCESS;
     }
 
-solve_cyc_tridiag_nonsym_END:
   if (zb != 0)
     free (zb);
   if (zu != 0)
@@ -417,6 +434,10 @@ solve_cyc_tridiag_nonsym_END:
   if (alpha != 0)
     free (alpha);
 
+  if (status == GSL_EZERODIV) {
+    GSL_ERROR ("matrix must be positive definite", status);
+  }
+
   return status;
 }
 
@@ -446,6 +467,7 @@ gsl_linalg_solve_symm_tridiag(
                            rhs->data, rhs->stride,
                            solution->data, solution->stride,
                            diag->size);
+
     }
 }
 
