@@ -1,10 +1,10 @@
 /* matrix/gsl_matrix_complex_float.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -114,6 +114,16 @@ gsl_matrix_complex_float_subdiagonal (gsl_matrix_complex_float * m, const size_t
 _gsl_vector_complex_float_view 
 gsl_matrix_complex_float_superdiagonal (gsl_matrix_complex_float * m, const size_t k);
 
+_gsl_vector_complex_float_view
+gsl_matrix_complex_float_subrow (gsl_matrix_complex_float * m,
+                                 const size_t i, const size_t offset,
+                                 const size_t n);
+
+_gsl_vector_complex_float_view
+gsl_matrix_complex_float_subcolumn (gsl_matrix_complex_float * m,
+                                    const size_t j, const size_t offset,
+                                    const size_t n);
+
 _gsl_matrix_complex_float_view
 gsl_matrix_complex_float_view_array (float * base,
                              const size_t n1, 
@@ -161,6 +171,16 @@ _gsl_vector_complex_float_const_view
 gsl_matrix_complex_float_const_superdiagonal (const gsl_matrix_complex_float * m, 
                                       const size_t k);
 
+_gsl_vector_complex_float_const_view
+gsl_matrix_complex_float_const_subrow (const gsl_matrix_complex_float * m,
+                                       const size_t i, const size_t offset,
+                                       const size_t n);
+
+_gsl_vector_complex_float_const_view
+gsl_matrix_complex_float_const_subcolumn (const gsl_matrix_complex_float * m,
+                                          const size_t j, const size_t offset,
+                                          const size_t n);
+
 _gsl_matrix_complex_float_const_view
 gsl_matrix_complex_float_const_view_array (const float * base,
                                    const size_t n1, 
