@@ -1,10 +1,10 @@
 /* matrix/gsl_matrix_long_double.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSL_MATRIX_LONG_DOUBLE_H__
@@ -116,6 +116,14 @@ gsl_matrix_long_double_subdiagonal (gsl_matrix_long_double * m, const size_t k);
 _gsl_vector_long_double_view 
 gsl_matrix_long_double_superdiagonal (gsl_matrix_long_double * m, const size_t k);
 
+_gsl_vector_long_double_view
+gsl_matrix_long_double_subrow (gsl_matrix_long_double * m, const size_t i,
+                         const size_t offset, const size_t n);
+
+_gsl_vector_long_double_view
+gsl_matrix_long_double_subcolumn (gsl_matrix_long_double * m, const size_t j,
+                            const size_t offset, const size_t n);
+
 _gsl_matrix_long_double_view
 gsl_matrix_long_double_view_array (long double * base,
                              const size_t n1, 
@@ -164,6 +172,14 @@ _gsl_vector_long_double_const_view
 gsl_matrix_long_double_const_superdiagonal (const gsl_matrix_long_double * m, 
                                       const size_t k);
 
+_gsl_vector_long_double_const_view
+gsl_matrix_long_double_const_subrow (const gsl_matrix_long_double * m, const size_t i,
+                               const size_t offset, const size_t n);
+
+_gsl_vector_long_double_const_view
+gsl_matrix_long_double_const_subcolumn (const gsl_matrix_long_double * m, const size_t j,
+                                  const size_t offset, const size_t n);
+
 _gsl_matrix_long_double_const_view
 gsl_matrix_long_double_const_view_array (const long double * base,
                                    const size_t n1, 
@@ -221,6 +237,9 @@ void gsl_matrix_long_double_min_index (const gsl_matrix_long_double * m, size_t
 void gsl_matrix_long_double_minmax_index (const gsl_matrix_long_double * m, size_t * imin, size_t * jmin, size_t * imax, size_t * jmax);
 
 int gsl_matrix_long_double_isnull (const gsl_matrix_long_double * m);
+int gsl_matrix_long_double_ispos (const gsl_matrix_long_double * m);
+int gsl_matrix_long_double_isneg (const gsl_matrix_long_double * m);
+int gsl_matrix_long_double_isnonneg (const gsl_matrix_long_double * m);
 
 int gsl_matrix_long_double_add (gsl_matrix_long_double * a, const gsl_matrix_long_double * b);
 int gsl_matrix_long_double_sub (gsl_matrix_long_double * a, const gsl_matrix_long_double * b);
@@ -240,7 +259,7 @@ int gsl_matrix_long_double_set_col(gsl_matrix_long_double * m, const size_t j, c
 
 /* inline functions if you are using GCC */
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 extern inline 
 long double
 gsl_matrix_long_double_get(const gsl_matrix_long_double * m, const size_t i, const size_t j)
