@@ -1,10 +1,10 @@
 /* matrix/gsl_matrix_uchar.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -116,6 +116,14 @@ gsl_matrix_uchar_subdiagonal (gsl_matrix_uchar * m, const size_t k);
 _gsl_vector_uchar_view 
 gsl_matrix_uchar_superdiagonal (gsl_matrix_uchar * m, const size_t k);
 
+_gsl_vector_uchar_view
+gsl_matrix_uchar_subrow (gsl_matrix_uchar * m, const size_t i,
+                         const size_t offset, const size_t n);
+
+_gsl_vector_uchar_view
+gsl_matrix_uchar_subcolumn (gsl_matrix_uchar * m, const size_t j,
+                            const size_t offset, const size_t n);
+
 _gsl_matrix_uchar_view
 gsl_matrix_uchar_view_array (unsigned char * base,
                              const size_t n1, 
@@ -164,6 +172,14 @@ _gsl_vector_uchar_const_view
 gsl_matrix_uchar_const_superdiagonal (const gsl_matrix_uchar * m, 
                                       const size_t k);
 
+_gsl_vector_uchar_const_view
+gsl_matrix_uchar_const_subrow (const gsl_matrix_uchar * m, const size_t i,
+                               const size_t offset, const size_t n);
+
+_gsl_vector_uchar_const_view
+gsl_matrix_uchar_const_subcolumn (const gsl_matrix_uchar * m, const size_t j,
+                                  const size_t offset, const size_t n);
+
 _gsl_matrix_uchar_const_view
 gsl_matrix_uchar_const_view_array (const unsigned char * base,
                                    const size_t n1, 
@@ -221,6 +237,9 @@ void gsl_matrix_uchar_min_index (const gsl_matrix_uchar * m, size_t * imin, size
 void gsl_matrix_uchar_minmax_index (const gsl_matrix_uchar * m, size_t * imin, size_t * jmin, size_t * imax, size_t * jmax);
 
 int gsl_matrix_uchar_isnull (const gsl_matrix_uchar * m);
+int gsl_matrix_uchar_ispos (const gsl_matrix_uchar * m);
+int gsl_matrix_uchar_isneg (const gsl_matrix_uchar * m);
+int gsl_matrix_uchar_isnonneg (const gsl_matrix_uchar * m);
 
 int gsl_matrix_uchar_add (gsl_matrix_uchar * a, const gsl_matrix_uchar * b);
 int gsl_matrix_uchar_sub (gsl_matrix_uchar * a, const gsl_matrix_uchar * b);
