@@ -1,10 +1,10 @@
 /* matrix/gsl_matrix_ushort.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSL_MATRIX_USHORT_H__
@@ -116,6 +116,14 @@ gsl_matrix_ushort_subdiagonal (gsl_matrix_ushort * m, const size_t k);
 _gsl_vector_ushort_view 
 gsl_matrix_ushort_superdiagonal (gsl_matrix_ushort * m, const size_t k);
 
+_gsl_vector_ushort_view
+gsl_matrix_ushort_subrow (gsl_matrix_ushort * m, const size_t i,
+                         const size_t offset, const size_t n);
+
+_gsl_vector_ushort_view
+gsl_matrix_ushort_subcolumn (gsl_matrix_ushort * m, const size_t j,
+                            const size_t offset, const size_t n);
+
 _gsl_matrix_ushort_view
 gsl_matrix_ushort_view_array (unsigned short * base,
                              const size_t n1, 
@@ -164,6 +172,14 @@ _gsl_vector_ushort_const_view
 gsl_matrix_ushort_const_superdiagonal (const gsl_matrix_ushort * m, 
                                       const size_t k);
 
+_gsl_vector_ushort_const_view
+gsl_matrix_ushort_const_subrow (const gsl_matrix_ushort * m, const size_t i,
+                               const size_t offset, const size_t n);
+
+_gsl_vector_ushort_const_view
+gsl_matrix_ushort_const_subcolumn (const gsl_matrix_ushort * m, const size_t j,
+                                  const size_t offset, const size_t n);
+
 _gsl_matrix_ushort_const_view
 gsl_matrix_ushort_const_view_array (const unsigned short * base,
                                    const size_t n1, 
@@ -221,6 +237,9 @@ void gsl_matrix_ushort_min_index (const gsl_matrix_ushort * m, size_t * imin, si
 void gsl_matrix_ushort_minmax_index (const gsl_matrix_ushort * m, size_t * imin, size_t * jmin, size_t * imax, size_t * jmax);
 
 int gsl_matrix_ushort_isnull (const gsl_matrix_ushort * m);
+int gsl_matrix_ushort_ispos (const gsl_matrix_ushort * m);
+int gsl_matrix_ushort_isneg (const gsl_matrix_ushort * m);
+int gsl_matrix_ushort_isnonneg (const gsl_matrix_ushort * m);
 
 int gsl_matrix_ushort_add (gsl_matrix_ushort * a, const gsl_matrix_ushort * b);
 int gsl_matrix_ushort_sub (gsl_matrix_ushort * a, const gsl_matrix_ushort * b);
