@@ -4,7 +4,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -28,6 +28,8 @@
 
 #include "test_funcs.h"
 
+unsigned int fcount, gcount;
+
 int
 test_fdf(const char * desc, gsl_multimin_function_fdf *f, 
          initpt_function initpt, const gsl_multimin_fdfminimizer_type *T);
@@ -38,7 +40,7 @@ test_f(const char * desc, gsl_multimin_function *f, initpt_function initpt);
 int
 main (void)
 {
-  const gsl_multimin_fdfminimizer_type *fdfminimizers[5];
+  const gsl_multimin_fdfminimizer_type *fdfminimizers[6];
   const gsl_multimin_fdfminimizer_type ** T;
 
   gsl_ieee_env_setup ();
@@ -47,7 +49,8 @@ main (void)
   fdfminimizers[1] = gsl_multimin_fdfminimizer_conjugate_pr;
   fdfminimizers[2] = gsl_multimin_fdfminimizer_conjugate_fr;
   fdfminimizers[3] = gsl_multimin_fdfminimizer_vector_bfgs;
-  fdfminimizers[4] = 0;
+  fdfminimizers[4] = gsl_multimin_fdfminimizer_vector_bfgs2;
+  fdfminimizers[5] = 0;
 
   T = fdfminimizers;
 
@@ -89,6 +92,7 @@ test_fdf(const char * desc,
   gsl_vector *x = gsl_vector_alloc (f->n);
 
   gsl_multimin_fdfminimizer *s;
+  fcount = 0; gcount = 0;
 
   (*initpt) (x);
 
@@ -123,8 +127,8 @@ test_fdf(const char * desc,
 
   status |= (fabs(s->f) > 1e-5);
 
-  gsl_test(status, "%s, on %s: %i iterations, f(x)=%g",
-           gsl_multimin_fdfminimizer_name(s),desc, iter, s->f);
+  gsl_test(status, "%s, on %s: %i iters (fn+g=%d+%d), f(x)=%g",
+           gsl_multimin_fdfminimizer_name(s),desc, iter, fcount, gcount, s->f);
 
   gsl_multimin_fdfminimizer_free(s);
   gsl_vector_free(x);
@@ -147,6 +151,7 @@ test_f(const char * desc, gsl_multimin_function *f, initpt_function initpt)
 
   gsl_multimin_fminimizer *s;
 
+  fcount = 0; gcount = 0;
   (*initpt) (x);
 
   for (i = 0; i < f->n; i++) 
@@ -180,8 +185,8 @@ test_f(const char * desc, gsl_multimin_function *f, initpt_function initpt)
 
   status |= (fabs(s->fval) > 1e-5);
 
-  gsl_test(status, "%s, on %s: %i iterations, f(x)=%g",
-           gsl_multimin_fminimizer_name(s),desc, iter, s->fval);
+  gsl_test(status, "%s, on %s: %d iter (fn=%d), f(x)=%g",
+           gsl_multimin_fminimizer_name(s),desc, iter, fcount, s->fval);
 
   gsl_multimin_fminimizer_free(s);
   gsl_vector_free(x);
