@@ -199,15 +199,32 @@ try_step:
   if (con != NULL)
     {
       /* Check error and attempt to adjust the step. */
+
+      double h_old = h0;
+
       const int hadjust_status 
         = gsl_odeiv_control_hadjust (con, step, y, e->yerr, e->dydt_out, &h0);
 
       if (hadjust_status == GSL_ODEIV_HADJ_DEC)
         {
-          /* Step was decreased. Undo and go back to try again. */
-          DBL_MEMCPY (y, e->y0, dydt->dimension);
-          e->failed_steps++;
-          goto try_step;
+          /* Check that the reported status is correct (i.e. an actual
+             decrease in h0 occured) and the suggested h0 will change
+             the time by at least 1 ulp */
+
+          double t_curr = GSL_COERCE_DBL(*t);
+          double t_next = GSL_COERCE_DBL((*t) + h0);
+
+          if (fabs(h0) < fabs(h_old) && t_next != t_curr) 
+            {
+              /* Step was decreased. Undo step, and try again with new h0. */
+              DBL_MEMCPY (y, e->y0, dydt->dimension);
+              e->failed_steps++;
+              goto try_step;
+            }
+          else
+            {
+              h0 = h_old; /* keep current step size */
+            }
         }
     }
 
