@@ -4,7 +4,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Runge-Kutta 4th order, Classical */
@@ -144,7 +144,7 @@ rk4_step (double *y, const rk4_state_t *state,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -160,7 +160,7 @@ rk4_step (double *y, const rk4_state_t *state,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -176,7 +176,7 @@ rk4_step (double *y, const rk4_state_t *state,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -221,7 +221,7 @@ rk4_apply (void *vstate,
 
       if (s != GSL_SUCCESS)
 	{
-	  return GSL_EBADFUNC;
+	  return s;
 	}
     }
 
@@ -267,7 +267,7 @@ rk4_apply (void *vstate,
       {
 	/* Restore original values */
 	DBL_MEMCPY (y, y0, dim);
-	return GSL_EBADFUNC;
+	return s;
       }
   }
   
@@ -297,7 +297,7 @@ rk4_apply (void *vstate,
       {
 	/* Restore original values */
 	DBL_MEMCPY (y, k1, dim);
-	return GSL_EBADFUNC;
+	return s;
       }
   }
   
