@@ -969,6 +969,206 @@ test_evolve_stiff5 (const gsl_odeiv_step_type * T, double h, double err)
                       "stiff[0,5]");
 }
 
+/* Test cases from Frank Reininghaus <frank78ac@googlemail.com> */
+
+int rhs_stepfn (double t, const double * y, double * dydt, void * params) {
+  if (t >= 1.0)
+    dydt [0] = 1;
+  else
+    dydt [0] = 0;
+
+  return GSL_SUCCESS;
+}
+
+void test_stepfn (void) {
+  /* infinite loop for epsabs = 1e-18, but not for 1e-17 */
+  double epsabs = 1e-18;
+  double epsrel = 1e-6;
+
+  const gsl_odeiv_step_type * T = gsl_odeiv_step_rk2;
+  gsl_odeiv_step * s = gsl_odeiv_step_alloc (T, 1);
+  gsl_odeiv_control * c = gsl_odeiv_control_y_new (epsabs, epsrel);
+  gsl_odeiv_evolve * e = gsl_odeiv_evolve_alloc (1);
+  gsl_odeiv_system sys = {rhs_stepfn, 0, 1, 0};
+     
+  double t = 0.0;
+  double h = 1e-6;
+  double y = 0.0;
+  int i = 0;
+  int status;
+
+  while (t < 2.0 && i < 1000000) {
+    status = gsl_odeiv_evolve_apply (e, c, s, &sys, &t, 2, &h, &y);
+#ifdef DEBUG
+    printf("i=%d status=%d t=%g h=%g y=%g\n", i, status, t, h, y);
+#endif
+    if (status != GSL_SUCCESS)
+      break;
+    
+    i++;
+  }
+
+  gsl_test_abs(t, 2.0, 1e-16, "evolve step function, t (stepfn/rk2)");
+  gsl_test_rel(y, 1.0, epsrel, "evolve step function, y (stepfn/rk2)");
+       
+  gsl_odeiv_evolve_free (e);
+  gsl_odeiv_control_free (c);
+  gsl_odeiv_step_free (s);
+}
+
+int rhs_stepfn2 (double t, const double * y, double * dydt, void * params) {
+  if (t >= 0.0)
+    dydt [0] = 1e300;
+  else
+    dydt [0] = 0;
+
+  return GSL_SUCCESS;
+}
+
+void test_stepfn2 (void) {
+  /* infinite loop for epsabs = 1e-25, but not for 1e-24 */
+  double epsabs = 1e-25;
+  double epsrel = 1e-6;
+
+  const gsl_odeiv_step_type * T = gsl_odeiv_step_rk2;
+  gsl_odeiv_step * s = gsl_odeiv_step_alloc (T, 1);
+  gsl_odeiv_control * c = gsl_odeiv_control_y_new (epsabs, epsrel);
+  gsl_odeiv_evolve * e = gsl_odeiv_evolve_alloc (1);
+  gsl_odeiv_system sys = {rhs_stepfn2, 0, 1, 0};
+     
+  double t = -1.0;
+  double h = 1e-6;
+  double y = 0.0;
+
+  int i = 0;
+  int status;
+
+  while (t < 1.0 && i < 10000) {
+    status = gsl_odeiv_evolve_apply (e, c, s, &sys, &t, 1.0, &h, &y);
+#ifdef DEBUG
+    printf("i=%d status=%d t=%g h=%g y=%g\n", i, status, t, h, y);
+#endif
+    if (status != GSL_SUCCESS)
+      break;
+
+    i++;
+  }
+
+  gsl_test_abs(t, 1.0, 1e-16, "evolve big step function, t (stepfn2/rk2)");
+  gsl_test_rel(y, 1e300, epsrel, "evolve big step function, y (stepfn2/rk2)");
+     
+  gsl_odeiv_evolve_free (e);
+  gsl_odeiv_control_free (c);
+  gsl_odeiv_step_free (s);
+}
+
+int rhs_stepfn3 (double t, const double * y, double * dydt, void * params) {
+
+  static int calls = 0;
+
+  if (t >= 0.0)
+    dydt [0] = 1e300;
+  else
+    dydt [0] = 0;
+
+  calls++;
+
+  return (calls < 100000) ? GSL_SUCCESS : -999;
+}
+
+
+void test_stepfn3 (void) {
+  /* infinite loop for epsabs = 1e-26, but not for 1e-25 */
+  double epsabs = 1e-26;
+  double epsrel = 1e-6;
+
+  const gsl_odeiv_step_type * T = gsl_odeiv_step_rkf45;
+  gsl_odeiv_step * s = gsl_odeiv_step_alloc (T, 1);
+  gsl_odeiv_control * c = gsl_odeiv_control_y_new (epsabs, epsrel);
+  gsl_odeiv_evolve * e = gsl_odeiv_evolve_alloc (1);
+  gsl_odeiv_system sys = {rhs_stepfn3, 0, 1, 0};
+     
+  double t = -1.0;
+  double h = 1e-6;
+  double y = 0.0;
+
+  int i = 0;
+  int status;
+
+  while (t < 1.0 && i < 10000) {
+    status = gsl_odeiv_evolve_apply (e, c, s, &sys, &t, 1.0, &h, &y);
+#ifdef DEBUG
+    printf("i=%d status=%d t=%g h=%g y=%g\n", i, status, t, h, y);
+#endif
+    if (status != GSL_SUCCESS)
+      break;
+
+    i++;
+  }
+
+  gsl_test_abs(t, 1.0, 1e-16, "evolve big step function, t (stepfn3/rkf45)");
+  gsl_test_rel(y, 1e300, epsrel, "evolve big step function, y (stepfn3/rkf45)");
+     
+  gsl_odeiv_evolve_free (e);
+  gsl_odeiv_control_free (c);
+  gsl_odeiv_step_free (s);
+}
+
+int rhs_cos (double t, const double * y, double * dydt, void * params) {
+  dydt [0] = cos (t);
+  return GSL_SUCCESS;
+}
+
+int jac_cos (double t, const double y[], double *dfdy, double dfdt[],
+             void *params)
+{
+  dfdy[0] = 0.0;
+  dfdt[0] = -sin(t);
+
+  return GSL_SUCCESS;
+}
+
+/* Test evolution in negative direction */
+
+void
+test_evolve_negative_h (const gsl_odeiv_step_type * T, double h, double err)
+{ 
+  /* Tolerance factor in testing errors */
+  const double factor = 10;
+
+  gsl_odeiv_step * step = gsl_odeiv_step_alloc (T, 1);
+  gsl_odeiv_control * c = gsl_odeiv_control_standard_new (err, err, 1.0, 0.0);
+  gsl_odeiv_evolve * e = gsl_odeiv_evolve_alloc (1);
+  gsl_odeiv_system sys = {rhs_cos, jac_cos, 1, 0};
+
+  double t = 0;
+  double t1 = -4.0;
+
+  double y = 0.0;
+  double yfin = sin (t1);
+
+  /* Make initial h negative */
+  h = -fabs(h);
+
+  while (t > t1) {
+    int status = gsl_odeiv_evolve_apply (e, c, step, &sys, &t, t1, &h, &y);
+    
+    if (status != GSL_SUCCESS) 
+      {
+	gsl_test(status, "%s evolve_apply returned %d for negative h",
+		 gsl_odeiv_step_name (step), status);
+	break;
+      }
+  }
+
+  gsl_test_abs (y, yfin, factor * e->count * err,
+		"evolution with negative h (using %s)", 
+                gsl_odeiv_step_name (step));
+
+  gsl_odeiv_evolve_free (e);
+  gsl_odeiv_control_free (c);
+  gsl_odeiv_step_free (step);
+}
 
 int
 main (void)
@@ -1021,10 +1221,15 @@ main (void)
       test_evolve_xsin (p[i].type, p[i].h, 1e-8);
       test_evolve_stiff1 (p[i].type, p[i].h, 1e-7);
       test_evolve_stiff5 (p[i].type, p[i].h, 1e-7);
+      test_evolve_negative_h (p[i].type, p[i].h, 1e-7);
     }
 
   test_compare_vanderpol();
   test_compare_oregonator();
-
+  
+  test_stepfn();
+  test_stepfn2();
+  test_stepfn3();
+ 
   exit (gsl_test_summary ());
 }
