@@ -1,4 +1,4 @@
-/* Author: G. Jungman
+/* Author: G. Jungman + modifications from O. Teytaud
  */
 #ifndef __GSL_QRNG_H__
 #define __GSL_QRNG_H__
@@ -52,6 +52,8 @@ gsl_qrng;
  */
 GSL_VAR const gsl_qrng_type * gsl_qrng_niederreiter_2;
 GSL_VAR const gsl_qrng_type * gsl_qrng_sobol;
+GSL_VAR const gsl_qrng_type * gsl_qrng_halton;
+GSL_VAR const gsl_qrng_type * gsl_qrng_reversehalton;
 
 
 /* Allocate and initialize a generator
@@ -66,39 +68,39 @@ int gsl_qrng_memcpy (gsl_qrng * dest, const gsl_qrng * src);
 
 
 /* Clone a generator. */
-gsl_qrng * gsl_qrng_clone (const gsl_qrng * r);
+gsl_qrng * gsl_qrng_clone (const gsl_qrng * q);
 
 
 /* Free a generator. */
-void gsl_qrng_free (gsl_qrng * r);
+void gsl_qrng_free (gsl_qrng * q);
 
 
 /* Intialize a generator. */
-void gsl_qrng_init (gsl_qrng * r);
+void gsl_qrng_init (gsl_qrng * q);
 
 
 /* Get the standardized name of the generator. */
-const char * gsl_qrng_name (const gsl_qrng * r);
+const char * gsl_qrng_name (const gsl_qrng * q);
 
 
 /* ISN'T THIS CONFUSING FOR PEOPLE?
   WHAT IF SOMEBODY TRIES TO COPY WITH THIS ???
   */
-size_t gsl_qrng_size (const gsl_qrng * r);
+size_t gsl_qrng_size (const gsl_qrng * q);
 
 
-void * gsl_qrng_state (const gsl_qrng * r);
+void * gsl_qrng_state (const gsl_qrng * q);
 
 
 /* Retrieve next vector in sequence. */
-int gsl_qrng_get (const gsl_qrng * r, double x[]);
+int gsl_qrng_get (const gsl_qrng * q, double x[]);
 
 
 #ifdef HAVE_INLINE
-extern inline int gsl_qrng_get (const gsl_qrng * r, double x[]);
-extern inline int gsl_qrng_get (const gsl_qrng * r, double x[])
+extern inline int gsl_qrng_get (const gsl_qrng * q, double x[]);
+extern inline int gsl_qrng_get (const gsl_qrng * q, double x[])
 {
-  return (r->type->get) (r->state, r->dimension, x);
+  return (q->type->get) (q->state, q->dimension, x);
 }
 
 #endif /* HAVE_INLINE */
