@@ -518,9 +518,9 @@ integrate (pdf_func * pdf, double a, double b)
   double result, abserr;
   size_t n = 1000;
   gsl_function f;  
-  f.function = &wrapper_function;
-  f.params = pdf;
   gsl_integration_workspace * w = gsl_integration_workspace_alloc (n);
+  f.function = &wrapper_function;
+  f.params = (void *)pdf;
   gsl_integration_qags (&f, a, b, 1e-16, 1e-4, n, w, &result, &abserr);
   gsl_integration_workspace_free (w);
   return result;
