@@ -1,10 +1,10 @@
 /* rng/rng.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 James Theiler, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -126,20 +126,28 @@ gsl_rng_uniform_pos (const gsl_rng * r)
   return x ;
 }
 
+/* Note: to avoid integer overflow in (range+1) we work with scale =
+   range/n = (max-min)/n rather than scale=(max-min+1)/n, this reduces
+   efficiency slightly but avoids having to check for the out of range
+   value.  Note that range is typically O(2^32) so the addition of 1
+   is negligible in most usage. */
+
 unsigned long int
 gsl_rng_uniform_int (const gsl_rng * r, unsigned long int n)
 {
   unsigned long int offset = r->type->min;
   unsigned long int range = r->type->max - offset;
-  unsigned long int scale = range / n;
+  unsigned long int scale;
   unsigned long int k;
 
-  if (n > range) 
+  if (n > range || n == 0) 
     {
-      GSL_ERROR_VAL ("n exceeds maximum value of generator",
-                        GSL_EINVAL, 0) ;
+      GSL_ERROR_VAL ("invalid n, either 0 or exceeds maximum value of generator",
+                     GSL_EINVAL, 0) ;
     }
 
+  scale = range / n;
+
   do
     {
       k = (((r->type->get) (r->state)) - offset) / scale;
