@@ -1,10 +1,10 @@
 /* roots/secant.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Reid Priedhorsky, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Reid Priedhorsky, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* secant.c -- secant root finding algorithm 
@@ -94,14 +94,14 @@ secant_iterate (void * vstate, gsl_function_fdf * fdf, double * root)
   state->f = f_new ;
   state->df = df_new ;
 
-  if (!finite (f_new))
+  if (!gsl_finite (f_new))
     {
-      GSL_ERROR ("function not continuous", GSL_EBADFUNC);
+      GSL_ERROR ("function value is not finite", GSL_EBADFUNC);
     }
 
-  if (!finite (df_new))
+  if (!gsl_finite (df_new))
     {
-      GSL_ERROR ("function not differentiable", GSL_EBADFUNC);
+      GSL_ERROR ("derivative value is not finite", GSL_EBADFUNC);
     }
       
   return GSL_SUCCESS;
