@@ -1,10 +1,10 @@
 /* vector/test.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -19,7 +19,7 @@
 
 #include <config.h>
 
-#if !GSL_RANGE_CHECK
+#if (!GSL_RANGE_CHECK) && defined(HAVE_INLINE)
 #undef GSL_RANGE_CHECK
 #define GSL_RANGE_CHECK 1
 #endif
@@ -206,6 +206,7 @@ main (void)
         }
     }
 
+#if GSL_RANGE_CHECK
   gsl_set_error_handler (&my_error_handler);
 
   for (N = 1; N < 1024; N *=2) 
@@ -228,6 +229,7 @@ main (void)
           test_complex_long_double_trap (stride, N);
         }
     }
+#endif
 
   exit (gsl_test_summary ());
 }
